@@ -7,24 +7,19 @@ import _ from 'lodash'
 import React from 'react'
 import { connect } from 'react-redux'
 import PropTypes from 'prop-types'
-import { AcmModal, AcmButton, AcmAlert } from '@stolostron/ui-components'
+import { AcmModal, AcmButton, AcmAlert } from '@open-cluster-management/ui-components'
 import { Spinner, ButtonVariant, Checkbox } from '@patternfly/react-core'
 import msgs from '../../nls/platform.properties'
 import { withRouter } from 'react-router-dom'
 import { REQUEST_STATUS } from '../../actions/index'
 import { removeResource, clearRequestStatus, receiveDelError, updateModal } from '../../actions/common'
+import { getSource } from '../../tableDefinitions/utils'
 
 class RemoveResourceModal extends React.Component {
   constructor(props) {
     super(props)
-    this.handleSubmitClick = this.handleSubmitClick.bind(this)
-    this.state = {
-      selected: [],
-    }
-  }
-
-  UNSAFE_componentWillMount() {
     const { data } = this.props
+    let initialSelected = []
     const placements = _.get(data, 'raw.status.placement', [])
     const placementBindings = placements.map(placement => {
       return {
@@ -60,8 +55,25 @@ class RemoveResourceModal extends React.Component {
         })
       }
     })
-    if (children.length > 0 && this.state.selected.length < 1) {
-      this.setState({selected: children})
+    const policyAutomationName = _.get(data, 'policyAutomation.metadata.name')
+    const policyAutomationNS = _.get(data, 'policyAutomation.metadata.namespace')
+    if (policyAutomationName && policyAutomationNS) {
+      const selfLink = `/apis/policy.open-cluster-management.io/v1beta1/namespaces/${policyAutomationNS}/policyautomations/${policyAutomationName}`
+      children.push({
+        // each policy has only one policyAutomation
+        // but could have multi placementBindings/placementRules
+        id: 0 + '-policyAutomation-' + policyAutomationName,
+        selfLink,
+        label: policyAutomationName + ' [PolicyAutomation]',
+        selected: true
+      })
+    }
+    if (children.length > 0) {
+      initialSelected = children
+    }
+    this.handleSubmitClick = this.handleSubmitClick.bind(this)
+    this.state = {
+      selected: initialSelected,
     }
   }
 
@@ -93,25 +105,37 @@ class RemoveResourceModal extends React.Component {
     case 'modal.remove-hcmcompliance.label':
       return this.state.selected.length > 0
         ? <div className='remove-app-modal-content' >
-          <div className='remove-app-modal-content-text' >
-            {msgs.get('modal.remove.policy.confirm', [data.name || data.Name || data.metadata.name], locale)}
-          </div>
-          <div>
-            {this.state.selected.map((child) => {
-              return (
-                <div className='remove-app-modal-content-data' key={child.id} >
-                  <Checkbox
-                    id={child.id}
-                    isChecked={this.state.selected.some((i) => {return (i.id === child.id && child.selected === true)})}
-                    onChange={this.toggleSelected}
-                    onKeyPress={this.toggleSelectedKeyboard.bind(this, child.id)}
-                    label={child.label}
-                    aria-label={child.id} />
-                </div>
+            <div className='remove-app-modal-content-text' >
+              {msgs.get('modal.remove.policy.confirm', [data.name || data.Name || data.metadata.name], locale)}
+            </div>
+            <div style={{ padding: '.5rem 0' }}>
+              {this.state.selected.map((child) => {
+                return (
+                  <div className='remove-app-modal-content-data' key={child.id} >
+                    <Checkbox
+                      id={child.id}
+                      isChecked={this.state.selected.some((i) => {return (i.id === child.id && child.selected === true)})}
+                      onChange={this.toggleSelected}
+                      onKeyPress={this.toggleSelectedKeyboard.bind(this, child.id)}
+                      label={child.label}
+                      aria-label={child.id} />
+                  </div>
+                )}
               )}
+            </div>
+            {getSource(data) !== 'Local' && (
+              <AcmAlert
+                isInline={true}
+                noClose={true}
+                variant="default"
+                title={msgs.get('modal.actions.external.alert.title', locale)}
+                message={msgs.get(
+                  'modal.actions.external.alert.message',
+                  locale
+                )}
+              />
             )}
           </div>
-        </div>
         : <p>
           {msgs.get('modal.remove.confirm', [data.name || data.Name || data.metadata.name], locale)}
         </p>
