@@ -11,6 +11,11 @@ import {
   getControls,
   getStandards,
   getAutomationLink,
+  getRemediationText,
+  getSource,
+  getSourceText,
+  getStatus,
+  getStatusText,
 } from './utils'
 import {
   breakWord,
@@ -45,6 +50,18 @@ export default {
       transforms: [wrappable],
       cellTransforms: [breakWord],
     },
+    {
+      label: 'status',
+      msgKey: 'table.header.status',
+      resourceKey: 'raw.spec.disabled',
+      searchable: true,
+      sortable: true,
+      sortLabel: 'status.text',
+      transforms: [wrappable],
+      cellTransforms: [breakWord],
+      transformFunction: getStatus,
+      textFunction: getStatusText,
+    },
     {
       label: 'remediation',
       msgKey: 'table.header.remediation',
@@ -54,6 +71,7 @@ export default {
       sortable: true,
       transforms: [wrappable],
       cellTransforms: [breakWord],
+      transformFunction: getRemediationText,
     },
     {
       label: 'violations',
@@ -66,6 +84,18 @@ export default {
       cellTransforms: [breakWord],
       transformFunction: getPolicyCompliantStatus,
     },
+    {
+      label: 'source',
+      msgKey: 'table.header.source',
+      resourceKey: 'source',
+      searchable: true,
+      sortable: true,
+      sortLabel: 'source.text',
+      transforms: [wrappable],
+      cellTransforms: [breakWord],
+      transformFunction: getSource,
+      textFunction: getSourceText,
+    },
     {
       label: 'controls',
       msgKey: 'table.header.controls',
@@ -98,6 +128,9 @@ export default {
     {
       label: 'automation',
       msgKey: 'table.header.automation',
+      resourceKey: 'policyAutomation.metadata.name',
+      sortable: true,
+      sortLabel: 'automation.rawData',
       transforms: [wrappable],
       transformFunction: getAutomationLink,
     },
@@ -119,7 +152,7 @@ export default {
     },
   ],
   sortBy: {
-    index: 6,
+    index: 8,
     direction: 'desc',
   }
 }
