@@ -10,7 +10,7 @@ import _ from 'lodash'
 import config from '../../server/lib/shared/config'
 import {
   AcmTable,
-} from '@stolostron/ui-components'
+} from '@open-cluster-management/ui-components'
 import {
   Label,
   LabelGroup,
@@ -25,9 +25,10 @@ import {
 import TableTimestamp from '../components/common/TableTimestamp'
 import msgs from '../nls/platform.properties'
 import TruncateText from '../components/common/TruncateText'
-import { LocaleContext } from '../components/common/LocaleContext'
 import purifyReactNode from '../utils/PurifyReactNode'
 import AutomationButton from '../components/common/AutomationButton'
+import ChannelLabels from '../components/common/ChannelLabels'
+import { getChannelLabel, normalizeChannelType } from '../utils/resource-helper'
 
 // use console.log(JSON.stringify(result, circular())) to test return result from transform
 export const transform = (items, def, locale) => {
@@ -75,6 +76,7 @@ export const transform = (items, def, locale) => {
   const keyFn = (item) => item.uid.toString()
   let addSubRows
   if (columns.colChild.length > 0) {
+    // eslint-disable-next-line react/display-name
     addSubRows = (item) => {
       const subRows = rows.rowChild.filter((row) => row.uid?.toString() === item.uid?.toString())
       return [
@@ -86,7 +88,6 @@ export const transform = (items, def, locale) => {
                   items={subRows}
                   columns={columns.colChild}
                   keyFn={keyFn}
-                  gridBreakPoint=''
                   showToolbar={false}
                   autoHidePagination
                   noBorders
@@ -110,6 +111,7 @@ export const transform = (items, def, locale) => {
 
 function pushRows(items, rows, def, locale) {
   let subUid = 0, expandable
+  const refetch = items.refetch
   items.forEach((item, index) => {
     expandable = false
     const rowChildObj = {}
@@ -132,9 +134,12 @@ function pushRows(items, rows, def, locale) {
       } else if (key.transformFunction && typeof key.transformFunction === 'function') {
         // Leverage the defined transformFunction to render content and store the raw value as metadata
         value = {
-          title: key.transformFunction(item, locale),
+          title: refetch ? key.transformFunction(item, locale, refetch) : key.transformFunction(item, locale),
           rawData: value
         }
+        if (key.textFunction && typeof key.textFunction === 'function') {
+          value.text = key.textFunction(item, locale)
+        }
       } else {
         value =  (value || value === 0) ? value : '-'
       }
@@ -286,14 +291,6 @@ export function createComplianceLink(item = {}, ...param){
       policyName = <Link to={`${config.contextPath}/all/${encodeURIComponent(item.metadata.namespace)}/${encodeURIComponent(item.metadata.name)}`}>{item.metadata.name}</Link>
     }
   }
-  if (_.get(item, 'raw.spec.disabled')) {
-    policyName = <div className='policy-table-name-ctr'>
-      {policyName}{' '} {' '}
-      <Label className='disabled-label'>
-        {msgs.get('policy.disabled.label', LocaleContext.locale)}
-      </Label>
-    </div>
-  }
   return policyName
 }
 
@@ -316,9 +313,9 @@ export function getPolicyCompliantStatus(item, locale) {
   const unknownCount = statusArray.length === 3 ? parseInt(statusArray[2], 10) : 0
   return (
     <div className='violationCell'>
-      { violationCount > 0 ?
-        <RedExclamationCircleIcon tooltip={msgs.get('table.tooltip.noncompliant', locale)} /> :
-        totalCount > unknownCount && <GreenCheckCircleIcon tooltip={msgs.get('table.tooltip.compliant', locale)} />}
+      { violationCount > 0
+        ? <RedExclamationCircleIcon tooltip={msgs.get('table.tooltip.noncompliant', locale)} />
+        : totalCount > unknownCount && <GreenCheckCircleIcon tooltip={msgs.get('table.tooltip.compliant', locale)} />}
       { unknownCount > 0 && <YellowExclamationTriangleIcon tooltip={tooltip} /> }
       {`${violationCount}/${totalCount}`}
     </div>
@@ -332,11 +329,12 @@ export function getClusterCompliantStatus(item, locale) {
   const unknownCount = parseInt(statusArray[2], 10)
   return (
     <div className='violationCell'>
-      { violationCount > 0 ?
-        <RedExclamationCircleIcon tooltip={msgs.get('table.tooltip.noncompliant', locale)} /> : unknownCount !== totalCount ?
-        <GreenCheckCircleIcon tooltip={msgs.get('table.tooltip.compliant', locale)} /> : null }
-      { unknownCount > 0 &&
-        <YellowExclamationTriangleIcon tooltip={msgs.get('table.tooltip.nostatus', locale)} /> }
+      { violationCount > 0
+        ? <RedExclamationCircleIcon tooltip={msgs.get('table.tooltip.noncompliant', locale)} />
+        : unknownCount !== totalCount
+          ? <GreenCheckCircleIcon tooltip={msgs.get('table.tooltip.compliant', locale)} />
+          : null }
+      { unknownCount > 0 && <YellowExclamationTriangleIcon tooltip={msgs.get('table.tooltip.nostatus', locale)} /> }
       {`${violationCount}/${totalCount}`}
     </div>
   )
@@ -350,6 +348,47 @@ export function getControls(item) {
   return formatAnnotationString(item, 'policy.open-cluster-management.io/controls')
 }
 
+export function getStatusText(item, locale) {
+  return _.get(item, 'raw.spec.disabled')
+    ? msgs.get('policy.status.disabled.label', locale)
+    : msgs.get('policy.status.enabled.label', locale)
+}
+
+export function getRemediationText(item, locale) {
+  const remediation = _.get(item, 'raw.spec.remediationAction')
+  if (['inform', 'enforce'].includes(remediation)) {
+    return msgs.get(`policy.remediation.${remediation}`, locale)
+  }
+  return remediation
+}
+
+export function getSourceText(item, locale) {
+  const source = _.get(item, 'source', {}) || {}
+  if (source.type) {
+    return getChannelLabel(normalizeChannelType(source.type), 0, locale)
+  } else if (_.get(item, 'external')) {
+    return msgs.get('policy.source.external', locale)
+  } else {
+    return msgs.get('policy.source.local', locale)
+  }
+}
+
+export function getSource(item, locale) {
+  const source = _.get(item, 'source', {}) || {}
+  if (source.type) {
+    return <ChannelLabels channels={[source]} locale={locale} />
+  } else {
+    return getSourceText(item, locale)
+  }
+}
+
+export function getStatus(item, locale, table=true) {
+  const status = getStatusText(item, locale)
+  return _.get(item, 'raw.spec.disabled') && table
+    ? <div className='pf-u-disabled-color-100'>{status}</div>
+    : status
+}
+
 export function getStandards(item) {
   return formatAnnotationString(item, 'policy.open-cluster-management.io/standards')
 }
@@ -367,30 +406,20 @@ export function formatAnnotationString(policy, annotationKey){
   return '-'
 }
 
-export function getAutomationLink(item, locale) {
+export function getAutomationLink(item, locale, refetch) {
   if (_.get(item, 'metadata.namespace')) {
     return (
-      <AutomationButton item={item} locale={locale}></AutomationButton>
+      <AutomationButton item={item} locale={locale} refetch={refetch}></AutomationButton>
     )
   }
   return '-'
 }
 
-export function getStatus(item, locale) {
-  const status = _.get(item, 'status', '-')
-  if (status.compliant){
-    return <StatusField status={status.compliant.toLowerCase()} text={msgs.get(`policy.status.${status.compliant.toLowerCase()}`, locale)} />
-  } else if (status && typeof(status)==='string' && status !== '-'){
-    return <StatusField status={status.toLowerCase()} text={msgs.get(`policy.status.${status.toLowerCase()}`, locale)} />
-  }
-  return '-'
-}
-
 export function getCompliancePolicyStatus(item, locale) {
   if (item.clusterNotCompliant && item.clusterNotCompliant.length > 0){
-    return <StatusField status='noncompliant' text={msgs.get('policy.status.noncompliant', locale)} />
+    return <StatusField status='noncompliant' text={msgs.get('policy.compliance.noncompliant', locale)} />
   }
-  return <StatusField status='compliant' text={msgs.get('policy.status.compliant', locale)} />
+  return <StatusField status='compliant' text={msgs.get('policy.compliance.compliant', locale)} />
 }
 
 export function createCompliancePolicyLink(item = {}, ...param){
@@ -508,7 +537,7 @@ export function getDecisionList(policy, locale) {
                 // If there's no status, there's no point in linking to the status page
                 let href=null, color='grey'
                 if (status !== 'nostatus') {
-                  href=`${config.contextPath}/all/${policy.metadata.namespace}/${policy.metadata.name}/status?clusterFilter=${cluster}&index=0`
+                  href=`${config.contextPath}/all/${policy.metadata.namespace}/${policy.metadata.name}/clusters?clusterFilter=${cluster}`
                   color='blue'
                 } else {
                   href=`${config.contextPath}/all/${policy.metadata.namespace}/${policy.metadata.name}`
@@ -545,3 +574,75 @@ export function getDecisionList(policy, locale) {
   }
   return statusList
 }
+
+// Create filter label values for violations, policy source, remediation, and status
+export const getTableFilters =(items, locale)=>{
+
+  // build array of source options dependent on data received
+    function getSourceOptions(items){
+      const filters = items.map(item => {
+        return {label: item['source'].text , value: item['source'].text }
+      })
+      const filteredArr = Array.from(new Set(filters.map(item => item.label))).map(label => {
+        return filters.find(item => item.label === label)
+      })
+      return filteredArr
+    }
+
+  return [
+    {
+      label: msgs.get('policy.violations', locale),
+      id: 'violations',
+      options: [
+        { label: msgs.get('policy.violations.false', locale), value: 'no-violation' },
+        { label: msgs.get('policy.violations.true', locale), value: 'violation'},
+        { label: msgs.get('policy.violations.unknown', locale), value: '-' },
+      ],
+      tableFilterFn: function (selectedValues, item){
+        const violationArray = item[this.id].rawData.split('/')
+        const checkCompliance = () => {
+          if (violationArray[0] !== '-'){
+            return violationArray[0] > 0 ? 'violation' : 'no-violation'
+          } else {
+            return '-'
+          }
+        }
+        return selectedValues.includes(
+          checkCompliance()
+        )
+      },
+    },
+    {
+      label: msgs.get('policy.source', locale),
+      id: 'source',
+      options: getSourceOptions(items),
+      tableFilterFn: function (selectedValues, item){
+        return selectedValues.includes(item['source'].text)
+      },
+    },
+    {
+      label: msgs.get('policy.remediation', locale),
+      id: 'remediation',
+      options: [
+        { label: msgs.get('policy.remediation.inform', locale), value: 'inform'},
+        { label: msgs.get('policy.remediation.enforce', locale), value: 'enforce'}
+      ],
+      tableFilterFn: function (selectedValues, item){
+        return selectedValues.includes(item['remediation'].rawData)
+      },
+      showEmptyOptions: true
+    },
+    {
+      label: msgs.get('policy.status', locale),
+      id: 'status',
+      options: [
+        { label: msgs.get('policy.status.enabled.label'), value: 'false'},
+        { label: msgs.get('policy.status.disabled.label'), value: 'true'}
+      ],
+      tableFilterFn: function (selectedValues, item){
+        return selectedValues.includes(item['status'].rawData.toString())
+      },
+      showEmptyOptions: true
+    },
+  ]
+}
