@@ -13,13 +13,18 @@ import { pageLoader, isPolicyStatusAvailable, isClusterTemplateStatusAvailable,
          action_verifyCreatePolicySelection, isClusterViolationsStatusAvailable, action_verifyClusterViolationsInListing,
          action_checkNotificationMessage, action_checkPolicyListingPageUserPermissions, action_verifyCredentialsInSidebar,
          action_verifyAnsibleInstallPrompt, action_scheduleAutomation, action_verifyHistoryPageWithMock,
-         action_checkAndClosePolicyAutomationPanel, action_mockAnsibleInstallQuery
+         action_verifyPolicyWithAutomation, action_verifyPolicyWithoutAutomation, action_checkAndClosePolicyAutomationPanel,
+         action_mockAnsibleInstallQuery
 } from '../support/views'
 
-Cypress.Commands.add('login', (OPTIONS_HUB_USER='', OPTIONS_HUB_PASSWORD='', OC_IDP='', force=false) => {
+Cypress.Commands.add('login', (OPTIONS_HUB_USER='', OPTIONS_HUB_PASSWORD='', OC_IDP='', OC_IDP_CONFIGURED=false, force=false) => {
   const user = OPTIONS_HUB_USER || Cypress.env('OPTIONS_HUB_USER')
   const password = OPTIONS_HUB_PASSWORD || Cypress.env('OPTIONS_HUB_PASSWORD')
+  const idp_configured = OC_IDP_CONFIGURED || Cypress.env('OC_IDP_CONFIGURED')
   let idp = OC_IDP || Cypress.env('OC_IDP')
+  if (user === 'kubeadmin') {
+    idp = 'kube:admin'
+  }
   const APIServer = Cypress.env('OPTIONS_HUB_CLUSTER_URL')
   cy.log(`Initiating login as ${user} idp ${idp}`)
 
@@ -27,42 +32,51 @@ Cypress.Commands.add('login', (OPTIONS_HUB_USER='', OPTIONS_HUB_PASSWORD='', OC_
   // handle login by setting cookie explicitly when running against localhost
   .then(() => {
     if (Cypress.config().baseUrl.includes('localhost')) {
+      let currentUser
       expect(APIServer).to.not.equal(undefined)
       // check who is the current user
       cy.exec('oc whoami', {failOnNonZeroExit: false}).then(res => {
-        const currentUser = res.stdout.replace('kube:admin', 'kubeadmin')
+        currentUser = res.stdout.replace('kube:admin', 'kubeadmin')
         cy.log(`Currently logged to 'oc' as ${currentUser}`)
+      })
+      .then(() => {
         if (currentUser != user || force) {  // do oc login as the required user
           cy.log(`Doing 'oc login' as ${user}`)
-          cy.exec(`oc login --server=${APIServer} -u ${user} -p ${password}`).then(res => cy.log(res.stdout))
+          cy.exec('oc login --server=${APIServer} -u ${TEST_USER} -p ${TEST_PASSWORD}', { 'log': false, 'env': { TEST_USER: user, TEST_PASSWORD: password } }).then(res => cy.log(res.stdout))
         }
       })
       .then(() => {
         cy.exec('oc whoami -t').then(res => {  // get token and set cookie and env var accordingly
           Cypress.env('token', res.stdout)
-          cy.setCookie('acm-access-token-cookie', Cypress.env('token'))
+          cy.log('Setting acm-access-token-cookie')
+          cy.setCookie('acm-access-token-cookie', Cypress.env('token'), { 'log': false })
         })
       })
     }
   })
   cy.visit('/multicloud/policies')
-  .get('body').then(body => {
+  cy.get('body').then(() => {
     // if not yet logged in, do the regular login through Web UI
-    if (body.find('.pf-c-page__header').length === 0) {
-      // Check if identity providers are configured
-      if (body.find('form').length === 0) {
-        if (user === 'kubeadmin') {
-          idp = 'kube:admin'
+    if (Cypress.$('body').find('.pf-c-page__header').length === 0) {
+      cy.get('div.pf-c-login').scrollIntoView().should('be.visible').then(() => {
+        // Check if identity providers are configured
+        if (idp_configured) {
+          cy.waitUntil(() =>cy.contains(idp).scrollIntoView().should('be.visible'))
+          cy.contains(idp).scrollIntoView().should('be.visible').click()
         }
-        cy.contains(idp).click()
-      }
-      cy.get('#inputUsername').click().focused().type(user)
-      cy.get('#inputPassword').click().focused().type(password)
-      cy.get('button[type="submit"]').click()
-      cy.get('.pf-c-page__header').should('exist')
+      })
+      .then(() => {
+        cy.waitUntil(() => cy.get('#inputUsername').scrollIntoView().should('be.visible'))
+        cy.get('#inputUsername').scrollIntoView().should('be.visible').click().focused().type(user)
+        cy.waitUntil(() => cy.get('#inputPassword').scrollIntoView().should('be.visible'))
+        cy.get('#inputPassword').scrollIntoView().should('be.visible').click().focused().type(password, { 'log': false })
+        cy.waitUntil(() => cy.get('button[type="submit"]').scrollIntoView().should('be.visible'))
+        cy.get('button[type="submit"]').scrollIntoView().should('be.visible').click()
+        cy.get('.pf-c-page__header').scrollIntoView().should('be.visible')
+      })
     }
   })
-  .CheckGrcMainPage()
+  cy.CheckGrcMainPage()
 })
 
 Cypress.Commands.add('reloadUntil', (condition, options) => {
@@ -144,12 +158,14 @@ Cypress.Commands.add('logout', () => {
   cy.log('Attempt to logout existing user')
   cy.get('.pf-c-app-launcher.pf-m-align-right.co-app-launcher.co-user-menu').then($btn => {
     //logout when test starts since we need to use the app idp user
-    cy.log('Logging out existing user')
-      .get($btn).click()
+    cy.waitUntil(() => cy.log('Logging out existing user').get($btn).scrollIntoView().should('be.visible'))
+    cy.log('Logging out existing user').get($btn).scrollIntoView().should('be.visible').click()
     if (Cypress.config().baseUrl.includes('localhost')) {
-      cy.contains('Logout').click().clearCookies()
+      cy.waitUntil(() => cy.contains('Logout').scrollIntoView().should('be.visible'))
+      cy.contains('Logout').scrollIntoView().should('be.visible').click().clearCookies()
     } else {
-      cy.contains('Logout').click()
+      cy.waitUntil(() => cy.contains('Logout').scrollIntoView().should('be.visible'))
+      cy.contains('Logout').scrollIntoView().should('be.visible').click()
       cy.location('pathname').should('match', new RegExp('/oauth/authorize(\\?.*)?$'))
     }
   })
@@ -173,7 +189,8 @@ Cypress.Commands.add('toggleYAMLeditor', (state = undefined) => {
         (e.textContent.includes('Off') && state === 'On') ||
         (e.textContent.includes('On') && state === 'Off'))
     {
-      cy.get('#edit-yaml').next('label').click()
+      cy.waitUntil(() => cy.get('#edit-yaml').next('label').scrollIntoView().should('be.visible'))
+      cy.get('#edit-yaml').next('label').scrollIntoView().should('be.visible').click()
     }
     return cy
   })
@@ -208,7 +225,7 @@ Cypress.Commands.add('waitForClusterViolationsStatus', (name, violationsCounter)
     .clearTableSearch()
 })
 
-// needs to be run on /multicloud/policies/all/{namespace}/{policy}/status page
+// needs to be run on /multicloud/policies/all/{namespace}/{policy}/clusters or /multicloud/policies/all/{namespace}/{policy}/templates page
 // see isClusterTemplateStatusAvailable()
 Cypress.Commands.add('waitForClusterTemplateStatus', (clusterViolations = {}) => {
   cy.waitUntil(() => { return isClusterTemplateStatusAvailable(clusterViolations) }, {'interval': 1000, 'timeout':60000})
@@ -244,12 +261,13 @@ Cypress.Commands.add('CheckGrcMainPage', () => {
   window.localStorage.setItem('acm-grc-refresh-interval', 5000)
   pageLoader.shouldNotExist()
   cy.get('.pf-c-page__main-section .pf-c-title').contains('Governance')
-  cy.get('.page-content-container > div').should('be.visible')
+  cy.get('.page-content-container > div').scrollIntoView().should('be.visible')
 })
 
 Cypress.Commands.add('FromGRCToCreatePolicyPage', () => {
-  cy.get('#create-policy').should('exist')
-  cy.get('#create-policy').should('have.attr', 'aria-disabled', 'false').click()
+  cy.get('#create-policy').scrollIntoView().should('be.visible')
+  cy.waitUntil(() => cy.get('#create-policy').should('have.attr', 'aria-disabled', 'false').and('be.visible'))
+  cy.get('#create-policy').should('have.attr', 'aria-disabled', 'false').and('be.visible').click()
   cy.location('pathname').should('eq', '/multicloud/policies/create')
   pageLoader.shouldNotExist()
   cy.get('.pf-c-page__main-section .pf-c-title').contains('Create policy')
@@ -258,25 +276,23 @@ Cypress.Commands.add('FromGRCToCreatePolicyPage', () => {
 Cypress.Commands.add('goToPolicyDetailsPage', (policyName, namespace='default', open=true) => {
   cy.get('.resource-table').within(()=>
   {
-    cy.get('input[aria-label="Search input"]').clear().type(policyName) // This action remains on multicloud/policies/all
+    // This action remains on multicloud/policies/all
+    cy.waitUntil(() => cy.get('input[aria-label="Search input"]').should('be.visible'))
+      .clear().type(policyName)
+    // Wait for search debounce
+    // eslint-disable-next-line cypress/no-unnecessary-waiting
+    cy.wait(500)
+
     if(open)
     {
-      cy.get('a').contains(policyName).click()
+      cy.waitUntil(() => cy.get('a').contains(policyName).scrollIntoView().should('be.visible'))
+      cy.get('a').contains(policyName).scrollIntoView().should('be.visible').click()
       cy.location('pathname').should('eq', '/multicloud/policies/all/'+namespace+'/'+policyName)
       pageLoader.shouldNotExist()
       cy.get('.pf-c-page__main-section .pf-c-title').contains(policyName)
     }
   })
 })
-// must be run on policy details page
-// Cypress.Commands.add('goToPolicyClusterPage', (policyName, policyConfig, clusterName) => {
-//   var namespace = policyConfig['namespace']
-//   cy.get('.one-cluster-status').children('a').contains(clusterName)
-//     .should('exist')
-//     .click({force: true})
-//   pageLoader.shouldNotExist()
-//   cy.location('pathname').should('eq', '/multicloud/policies/policy/'+clusterName+'/'+namespace+'.'+policyName)
-// })
 
 Cypress.Commands.add('createPolicyFromSelection', (uPolicyName, create=true, policyConfig) => {
   cy.then(() => action_createPolicyFromSelection(uPolicyName, create, policyConfig))
@@ -347,9 +363,11 @@ Cypress.Commands.add('verifyCardsOnPolicyListingPage', (cardName, cardValuesDict
   const numCards = Object.keys(cardValuesDict).length
   cy.url().should('match', /\/multicloud\/policies\/all[?]?/)
   // switch to the required card
-  cy.get('#grc-cards-toggle').click()
+  cy.waitUntil(() => cy.get('#grc-cards-toggle').scrollIntoView().should('be.visible'))
+  cy.get('#grc-cards-toggle').scrollIntoView().should('be.visible').click()
   cy.get('div.module-grc-cards').within(() => {
-    cy.get('li').contains(cardName).click()
+    cy.waitUntil(() => cy.get('li').contains(cardName).scrollIntoView().should('be.visible'))
+    cy.get('li').contains(cardName).scrollIntoView().should('be.visible').click()
   })
   // check the summary header and counter
   cy.get('#summary-toggle').within(() => {
@@ -381,10 +399,11 @@ Cypress.Commands.add('verifyCardsOnPolicyListingPage', (cardName, cardValuesDict
 // click on the button to set content visibility on or off
 Cypress.Commands.add('toggleVisibilityButton', (buttonSelector, contentSelector, state='') => {
   cy.get(contentSelector).then($content => {
-    if ((state == '') ||  // either we want to do the switch
-        (state == 'off' && $content.is(':visible')) ||  // or it is visible and we want to hide it
-        (state == 'on' && $content.is(':visible') == false)) {  // or it is hidden and we want to show it
-      cy.get(buttonSelector).click()
+    if ((state === '') ||  // either we want to do the switch
+        (state === 'off' && $content.is(':visible')) ||  // or it is visible and we want to hide it
+        (state === 'on' && !$content.is(':visible'))) {  // or it is hidden and we want to show it
+      cy.waitUntil(() => cy.get(buttonSelector).scrollIntoView().should('be.visible'))
+      cy.get(buttonSelector).scrollIntoView().should('be.visible').click()
     }
   })
 })
@@ -437,7 +456,7 @@ Cypress.Commands.add('checkPolicyNoResourcesIconMessage', (present=true, message
   else
   {
     cy.get('.no-resource-title').should('contain', message)
-    cy.get('img[alt="No resource"]').should('exist')
+    cy.get('img[alt="No resource"]').scrollIntoView().should('be.visible')
   }
 })
 
@@ -468,7 +487,8 @@ Cypress.Commands.add('checkPolicyListingPageUserPermissions', (policyNames = [],
 Cypress.Commands.add('fromGRCToPolicyDetailsPage', (policyName) => {
   cy.doTableSearch(policyName)
     .get('.grc-view-by-policies-table').within(() => {
-      cy.get('a').contains(new RegExp(`^${policyName}$`)).click()
+      cy.waitUntil(() => cy.get('a').contains(new RegExp(`^${policyName}$`)).scrollIntoView().should('be.visible'))
+      cy.get('a').contains(new RegExp(`^${policyName}$`)).scrollIntoView().should('be.visible').click()
     })
 })
 
@@ -523,12 +543,20 @@ Cypress.Commands.add('verifyAnsibleInstallPrompt', (uPolicyName, opInstalled) =>
   cy.then(() => action_verifyAnsibleInstallPrompt(uPolicyName, opInstalled))
 })
 
-Cypress.Commands.add('scheduleAutomation', (uName, credentialName, mode) => {
-  cy.then(() => action_scheduleAutomation(uName, credentialName, mode))
+Cypress.Commands.add('scheduleAutomation', (uName, credentialName, mode, action) => {
+  cy.then(() => action_scheduleAutomation(uName, credentialName, mode, action))
 })
 
-Cypress.Commands.add('verifyHistoryPageWithMock', (uName, successful) => {
-  cy.then(() => action_verifyHistoryPageWithMock(uName, successful))
+Cypress.Commands.add('verifyHistoryPageWithMock', (uName) => {
+  cy.then(() => action_verifyHistoryPageWithMock(uName))
+})
+
+Cypress.Commands.add('verifyPolicyWithAutomation', (uPolicyName) => {
+  cy.then(() => action_verifyPolicyWithAutomation(uPolicyName))
+})
+
+Cypress.Commands.add('verifyPolicyWithoutAutomation', (uPolicyName) => {
+  cy.then(() => action_verifyPolicyWithoutAutomation(uPolicyName))
 })
 
 Cypress.Commands.add('checkAndClosePolicyAutomationPanel', (uName) => {
@@ -538,3 +566,4 @@ Cypress.Commands.add('checkAndClosePolicyAutomationPanel', (uName) => {
 Cypress.Commands.add('mockAnsibleInstallQuery', (opInstalled) => {
   cy.then(() => action_mockAnsibleInstallQuery(opInstalled))
 })
+
