@@ -19,14 +19,14 @@ describeT('RHACM4K-2354 - GRC UI: [P1][Sev1][console] Check existent and non-exi
   it('Verify URLs for Namespace and policy that do exist', () => {
     cy.visit('/multicloud/policies/all/default/'+policyName).waitForPageContentLoad()
     .checkPolicyNoResourcesIconMessage()
-    cy.visit('/multicloud/policies/all/default/'+policyName+'/status').waitForPageContentLoad()
+    cy.visit('/multicloud/policies/all/default/'+policyName+'/clusters').waitForPageContentLoad()
     .checkPolicyNoResourcesIconMessage()
   })
   it('Verify URLs for Namespace and policy that dont exist', () => {
     cy.visit('/multicloud/policies/all/not-a-namespace/not-a-policy').waitForPageContentLoad()
     .checkPolicyNoResourcesIconMessage(false, 'Resource not found')
-    cy.visit('/multicloud/policies/all/not-a-namespace/not-a-policy/status').waitForPageContentLoad()
-    .checkPolicyNoResourcesIconMessage(false, 'No policy status found')
+    cy.visit('/multicloud/policies/all/not-a-namespace/not-a-policy/clusters').waitForPageContentLoad()
+    .checkPolicyNoResourcesIconMessage(false, 'Resource not found')
   })
   it('Delete the policy', () => {
     cy.visit('/multicloud/policies/all').waitForPageContentLoad()
