@@ -7,6 +7,8 @@
  * Contract with IBM Corp.
  *******************************************************************************/
 /* Copyright (c) 2020 Red Hat, Inc. */
+/* Copyright Contributors to the Open Cluster Management project */
+
 
 'use strict'
 
@@ -19,10 +21,17 @@ describe('ResourceTableRowMenuItemActions', () => {
       'name': 'HCMCompliance',
       'query': 'ALL_POLICIES'
     }
+    const data = {
+      namespace: 'default',
+      name: 'policy-pod'
+    }
+    const history = { push: jest.fn() }
     const dispatch = jest.fn()
-    expect(resourceActions(action, dispatch, resourceType, {}, true, {})).toBeUndefined()
-    expect(dispatch).toHaveBeenCalledTimes(1)
-    expect(dispatch.mock.calls[0]).toMatchSnapshot()
+    expect(resourceActions(action, dispatch, resourceType, data, history)).toBeUndefined()
+    expect(dispatch).not.toHaveBeenCalled()
+    expect(history.push).toHaveBeenCalledTimes(1)
+    expect(history.push.mock.calls[0]).toMatchSnapshot()
+    history.push.mockClear()
   })
   it('table.actions.launch.cluster is called as expected', () => {
     const action = 'table.actions.launch.cluster'
