@@ -1,7 +1,8 @@
 import * as React from 'react';
 import { Body as BaseBody } from './base';
 import { RowType, RowKeyType } from './base/types';
-import { TableContext, IRow, IRowCell, IExtraRowData } from './Table';
+import { IRow, IRowCell, IExtraRowData } from './TableTypes';
+import { TableContext } from './TableContext';
 import { isRowExpanded } from './utils';
 
 export interface IComputedData {
@@ -10,7 +11,7 @@ export interface IComputedData {
 }
 
 export type OnRowClick = (
-  event: React.MouseEvent,
+  event: React.KeyboardEvent | React.MouseEvent,
   row: IRow,
   rowProps: IExtraRowData,
   computedData: IComputedData
@@ -19,22 +20,22 @@ export type OnRowClick = (
 export interface TableBodyProps {
   /** Additional classes added to the TableBody  */
   className?: string;
-  /** This prop should not be set manually  */
+  /** @hide This prop should not be set manually  */
   children?: React.ReactNode;
-  /** This prop should not be set manually  */
+  /** @hide This prop should not be set manually  */
   headerData?: IRow[];
-  /** This prop should not be set manually  */
+  /** @hide This prop should not be set manually  */
   rows?: IRow[];
-  /** This prop should not be set manually  */
+  /** @hide This prop should not be set manually  */
   rowKey?: RowKeyType;
-  /** This prop should not be set manually  */
+  /** A click handler for the row  */
   onRowClick?: OnRowClick;
-  /** This prop should not be set manually  */
+  /** @hide This prop should not be set manually  */
   onRow?: Function;
 }
 
 const flagVisibility = (rows: IRow[]) => {
-  const visibleRows = (rows as []).filter((oneRow: IRow) => !oneRow.parent || oneRow.isExpanded) as IRow[];
+  const visibleRows = (rows as IRow[]).filter((oneRow: IRow) => !oneRow.parent || oneRow.isExpanded) as IRow[];
   if (visibleRows.length > 0) {
     visibleRows[0].isFirstVisible = true;
     visibleRows[visibleRows.length - 1].isLastVisible = true;
@@ -55,13 +56,23 @@ class ContextBody extends React.Component<TableBodyProps, {}> {
     return {
       row,
       rowProps: extendedRowProps,
-      onMouseDown: (event: React.MouseEvent) => {
+      onClick: (event: React.MouseEvent) => {
         const computedData = {
           isInput: (event.target as HTMLElement).tagName !== 'INPUT',
           isButton: (event.target as HTMLElement).tagName !== 'BUTTON'
         };
 
         onRowClick(event, row, rowProps, computedData);
+      },
+      onKeyDown: (event: React.KeyboardEvent) => {
+        if (event.key === 'Enter' || event.key === ' ') {
+          const computedData = {
+            isInput: (event.target as HTMLElement).tagName !== 'INPUT',
+            isButton: (event.target as HTMLElement).tagName !== 'BUTTON'
+          };
+          onRowClick(event, row, rowProps, computedData);
+          event.preventDefault();
+        }
       }
     };
   };
@@ -90,13 +101,15 @@ class ContextBody extends React.Component<TableBodyProps, {}> {
               // to the first user column's header formatters
               formatters = headerData[firstUserColumnIndex].cell.formatters;
             }
+            let mappedCellTitle: IRowCell | Function | IRowCell['title'] = cell;
+            if (isCellObject && isCellFunction) {
+              mappedCellTitle = (cell.title as Function)(cell.props.value, rowKey, cellIndex, cell.props);
+            } else if (isCellObject) {
+              mappedCellTitle = cell.title;
+            }
             const mappedCell: IMappedCell = {
               [headerData[cellIndex + additionalColsIndexShift].property]: {
-                title: isCellObject
-                  ? isCellFunction
-                    ? (cell.title as Function)(cell.props.value, rowKey, cellIndex, cell.props)
-                    : cell.title
-                  : cell,
+                title: mappedCellTitle,
                 formatters,
                 props: {
                   isVisible: true,
@@ -114,7 +127,7 @@ class ContextBody extends React.Component<TableBodyProps, {}> {
               ...mappedCell
             };
           },
-          { id: row.id !== undefined ? row.id : rowKey }
+          { secretTableRowKeyId: row.id !== undefined ? row.id : rowKey }
         ))
     };
   };
@@ -125,7 +138,7 @@ class ContextBody extends React.Component<TableBodyProps, {}> {
 
     let mappedRows: IRow[];
     if (headerData.length > 0) {
-      mappedRows = (rows as []).map((oneRow: IRow, oneRowKey: number) => ({
+      mappedRows = (rows as IRow[]).map((oneRow: IRow, oneRowKey: number) => ({
         ...oneRow,
         ...this.mapCells(headerData, oneRow, oneRowKey),
         isExpanded: isRowExpanded(oneRow, rows),
@@ -158,10 +171,15 @@ class ContextBody extends React.Component<TableBodyProps, {}> {
 export const TableBody = ({
   className = '' as string,
   children = null as React.ReactNode,
-  rowKey = 'id' as string,
+  rowKey = 'secretTableRowKeyId' as string,
   /* eslint-disable @typescript-eslint/no-unused-vars */
-  onRow = (...args: any) => Object,
-  onRowClick = (event: React.MouseEvent, row: IRow, rowProps: IExtraRowData, computedData: IComputedData) =>
+  onRow = (...args: any) => ({}),
+  onRowClick = (
+    event: React.MouseEvent | React.KeyboardEvent,
+    row: IRow,
+    rowProps: IExtraRowData,
+    computedData: IComputedData
+  ) =>
     /* eslint-enable @typescript-eslint/no-unused-vars */
     undefined as OnRowClick,
   ...props
